@@ -28,7 +28,9 @@ __all__ = (
     "ListTablesPaginatorName",
     "StatementStatusStringType",
     "StatusStringType",
+    "RedshiftDataAPIServiceServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -43,6 +45,7 @@ StatementStatusStringType = Literal[
     "ABORTED", "FAILED", "FINISHED", "PICKED", "STARTED", "SUBMITTED"
 ]
 StatusStringType = Literal["ABORTED", "ALL", "FAILED", "FINISHED", "PICKED", "STARTED", "SUBMITTED"]
+RedshiftDataAPIServiceServiceName = Literal["redshift-data"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -74,6 +77,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -196,6 +200,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -344,6 +349,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_table",
     "get_statement_result",
