@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import StatementStatusStringType, StatusStringType
 
 if sys.version_info >= (3, 9):
@@ -54,32 +56,18 @@ __all__ = (
     "TableMemberTypeDef",
 )
 
-_RequiredBatchExecuteStatementInputRequestTypeDef = TypedDict(
-    "_RequiredBatchExecuteStatementInputRequestTypeDef",
+BatchExecuteStatementInputRequestTypeDef = TypedDict(
+    "BatchExecuteStatementInputRequestTypeDef",
     {
         "Database": str,
         "Sqls": Sequence[str],
+        "ClusterIdentifier": NotRequired[str],
+        "DbUser": NotRequired[str],
+        "SecretArn": NotRequired[str],
+        "StatementName": NotRequired[str],
+        "WithEvent": NotRequired[bool],
     },
 )
-_OptionalBatchExecuteStatementInputRequestTypeDef = TypedDict(
-    "_OptionalBatchExecuteStatementInputRequestTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "DbUser": str,
-        "SecretArn": str,
-        "StatementName": str,
-        "WithEvent": bool,
-    },
-    total=False,
-)
-
-
-class BatchExecuteStatementInputRequestTypeDef(
-    _RequiredBatchExecuteStatementInputRequestTypeDef,
-    _OptionalBatchExecuteStatementInputRequestTypeDef,
-):
-    pass
-
 
 BatchExecuteStatementOutputTypeDef = TypedDict(
     "BatchExecuteStatementOutputTypeDef",
@@ -112,21 +100,20 @@ CancelStatementResponseTypeDef = TypedDict(
 ColumnMetadataTypeDef = TypedDict(
     "ColumnMetadataTypeDef",
     {
-        "columnDefault": str,
-        "isCaseSensitive": bool,
-        "isCurrency": bool,
-        "isSigned": bool,
-        "label": str,
-        "length": int,
-        "name": str,
-        "nullable": int,
-        "precision": int,
-        "scale": int,
-        "schemaName": str,
-        "tableName": str,
-        "typeName": str,
+        "columnDefault": NotRequired[str],
+        "isCaseSensitive": NotRequired[bool],
+        "isCurrency": NotRequired[bool],
+        "isSigned": NotRequired[bool],
+        "label": NotRequired[str],
+        "length": NotRequired[int],
+        "name": NotRequired[str],
+        "nullable": NotRequired[int],
+        "precision": NotRequired[int],
+        "scale": NotRequired[int],
+        "schemaName": NotRequired[str],
+        "tableName": NotRequired[str],
+        "typeName": NotRequired[str],
     },
-    total=False,
 )
 
 DescribeStatementRequestRequestTypeDef = TypedDict(
@@ -161,33 +148,20 @@ DescribeStatementResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDescribeTableRequestRequestTypeDef = TypedDict(
-    "_RequiredDescribeTableRequestRequestTypeDef",
+DescribeTableRequestRequestTypeDef = TypedDict(
+    "DescribeTableRequestRequestTypeDef",
     {
         "Database": str,
+        "ClusterIdentifier": NotRequired[str],
+        "ConnectedDatabase": NotRequired[str],
+        "DbUser": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "Schema": NotRequired[str],
+        "SecretArn": NotRequired[str],
+        "Table": NotRequired[str],
     },
 )
-_OptionalDescribeTableRequestRequestTypeDef = TypedDict(
-    "_OptionalDescribeTableRequestRequestTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "ConnectedDatabase": str,
-        "DbUser": str,
-        "MaxResults": int,
-        "NextToken": str,
-        "Schema": str,
-        "SecretArn": str,
-        "Table": str,
-    },
-    total=False,
-)
-
-
-class DescribeTableRequestRequestTypeDef(
-    _RequiredDescribeTableRequestRequestTypeDef, _OptionalDescribeTableRequestRequestTypeDef
-):
-    pass
-
 
 DescribeTableResponseTypeDef = TypedDict(
     "DescribeTableResponseTypeDef",
@@ -199,32 +173,19 @@ DescribeTableResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredExecuteStatementInputRequestTypeDef = TypedDict(
-    "_RequiredExecuteStatementInputRequestTypeDef",
+ExecuteStatementInputRequestTypeDef = TypedDict(
+    "ExecuteStatementInputRequestTypeDef",
     {
         "Database": str,
         "Sql": str,
+        "ClusterIdentifier": NotRequired[str],
+        "DbUser": NotRequired[str],
+        "Parameters": NotRequired[Sequence["SqlParameterTypeDef"]],
+        "SecretArn": NotRequired[str],
+        "StatementName": NotRequired[str],
+        "WithEvent": NotRequired[bool],
     },
 )
-_OptionalExecuteStatementInputRequestTypeDef = TypedDict(
-    "_OptionalExecuteStatementInputRequestTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "DbUser": str,
-        "Parameters": Sequence["SqlParameterTypeDef"],
-        "SecretArn": str,
-        "StatementName": str,
-        "WithEvent": bool,
-    },
-    total=False,
-)
-
-
-class ExecuteStatementInputRequestTypeDef(
-    _RequiredExecuteStatementInputRequestTypeDef, _OptionalExecuteStatementInputRequestTypeDef
-):
-    pass
-
 
 ExecuteStatementOutputTypeDef = TypedDict(
     "ExecuteStatementOutputTypeDef",
@@ -242,37 +203,22 @@ ExecuteStatementOutputTypeDef = TypedDict(
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
-        "blobValue": bytes,
-        "booleanValue": bool,
-        "doubleValue": float,
-        "isNull": bool,
-        "longValue": int,
-        "stringValue": str,
+        "blobValue": NotRequired[bytes],
+        "booleanValue": NotRequired[bool],
+        "doubleValue": NotRequired[float],
+        "isNull": NotRequired[bool],
+        "longValue": NotRequired[int],
+        "stringValue": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredGetStatementResultRequestRequestTypeDef = TypedDict(
-    "_RequiredGetStatementResultRequestRequestTypeDef",
+GetStatementResultRequestRequestTypeDef = TypedDict(
+    "GetStatementResultRequestRequestTypeDef",
     {
         "Id": str,
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalGetStatementResultRequestRequestTypeDef = TypedDict(
-    "_OptionalGetStatementResultRequestRequestTypeDef",
-    {
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class GetStatementResultRequestRequestTypeDef(
-    _RequiredGetStatementResultRequestRequestTypeDef,
-    _OptionalGetStatementResultRequestRequestTypeDef,
-):
-    pass
-
 
 GetStatementResultResponseTypeDef = TypedDict(
     "GetStatementResultResponseTypeDef",
@@ -285,30 +231,17 @@ GetStatementResultResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListDatabasesRequestRequestTypeDef = TypedDict(
-    "_RequiredListDatabasesRequestRequestTypeDef",
+ListDatabasesRequestRequestTypeDef = TypedDict(
+    "ListDatabasesRequestRequestTypeDef",
     {
         "Database": str,
+        "ClusterIdentifier": NotRequired[str],
+        "DbUser": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "SecretArn": NotRequired[str],
     },
 )
-_OptionalListDatabasesRequestRequestTypeDef = TypedDict(
-    "_OptionalListDatabasesRequestRequestTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "DbUser": str,
-        "MaxResults": int,
-        "NextToken": str,
-        "SecretArn": str,
-    },
-    total=False,
-)
-
-
-class ListDatabasesRequestRequestTypeDef(
-    _RequiredListDatabasesRequestRequestTypeDef, _OptionalListDatabasesRequestRequestTypeDef
-):
-    pass
-
 
 ListDatabasesResponseTypeDef = TypedDict(
     "ListDatabasesResponseTypeDef",
@@ -319,32 +252,19 @@ ListDatabasesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListSchemasRequestRequestTypeDef = TypedDict(
-    "_RequiredListSchemasRequestRequestTypeDef",
+ListSchemasRequestRequestTypeDef = TypedDict(
+    "ListSchemasRequestRequestTypeDef",
     {
         "Database": str,
+        "ClusterIdentifier": NotRequired[str],
+        "ConnectedDatabase": NotRequired[str],
+        "DbUser": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "SchemaPattern": NotRequired[str],
+        "SecretArn": NotRequired[str],
     },
 )
-_OptionalListSchemasRequestRequestTypeDef = TypedDict(
-    "_OptionalListSchemasRequestRequestTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "ConnectedDatabase": str,
-        "DbUser": str,
-        "MaxResults": int,
-        "NextToken": str,
-        "SchemaPattern": str,
-        "SecretArn": str,
-    },
-    total=False,
-)
-
-
-class ListSchemasRequestRequestTypeDef(
-    _RequiredListSchemasRequestRequestTypeDef, _OptionalListSchemasRequestRequestTypeDef
-):
-    pass
-
 
 ListSchemasResponseTypeDef = TypedDict(
     "ListSchemasResponseTypeDef",
@@ -358,13 +278,12 @@ ListSchemasResponseTypeDef = TypedDict(
 ListStatementsRequestRequestTypeDef = TypedDict(
     "ListStatementsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
-        "RoleLevel": bool,
-        "StatementName": str,
-        "Status": StatusStringType,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "RoleLevel": NotRequired[bool],
+        "StatementName": NotRequired[str],
+        "Status": NotRequired[StatusStringType],
     },
-    total=False,
 )
 
 ListStatementsResponseTypeDef = TypedDict(
@@ -376,33 +295,20 @@ ListStatementsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListTablesRequestRequestTypeDef = TypedDict(
-    "_RequiredListTablesRequestRequestTypeDef",
+ListTablesRequestRequestTypeDef = TypedDict(
+    "ListTablesRequestRequestTypeDef",
     {
         "Database": str,
+        "ClusterIdentifier": NotRequired[str],
+        "ConnectedDatabase": NotRequired[str],
+        "DbUser": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "SchemaPattern": NotRequired[str],
+        "SecretArn": NotRequired[str],
+        "TablePattern": NotRequired[str],
     },
 )
-_OptionalListTablesRequestRequestTypeDef = TypedDict(
-    "_OptionalListTablesRequestRequestTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "ConnectedDatabase": str,
-        "DbUser": str,
-        "MaxResults": int,
-        "NextToken": str,
-        "SchemaPattern": str,
-        "SecretArn": str,
-        "TablePattern": str,
-    },
-    total=False,
-)
-
-
-class ListTablesRequestRequestTypeDef(
-    _RequiredListTablesRequestRequestTypeDef, _OptionalListTablesRequestRequestTypeDef
-):
-    pass
-
 
 ListTablesResponseTypeDef = TypedDict(
     "ListTablesResponseTypeDef",
@@ -416,11 +322,10 @@ ListTablesResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -442,67 +347,44 @@ SqlParameterTypeDef = TypedDict(
     },
 )
 
-_RequiredStatementDataTypeDef = TypedDict(
-    "_RequiredStatementDataTypeDef",
+StatementDataTypeDef = TypedDict(
+    "StatementDataTypeDef",
     {
         "Id": str,
+        "CreatedAt": NotRequired[datetime],
+        "IsBatchStatement": NotRequired[bool],
+        "QueryParameters": NotRequired[List["SqlParameterTypeDef"]],
+        "QueryString": NotRequired[str],
+        "QueryStrings": NotRequired[List[str]],
+        "SecretArn": NotRequired[str],
+        "StatementName": NotRequired[str],
+        "Status": NotRequired[StatusStringType],
+        "UpdatedAt": NotRequired[datetime],
     },
 )
-_OptionalStatementDataTypeDef = TypedDict(
-    "_OptionalStatementDataTypeDef",
-    {
-        "CreatedAt": datetime,
-        "IsBatchStatement": bool,
-        "QueryParameters": List["SqlParameterTypeDef"],
-        "QueryString": str,
-        "QueryStrings": List[str],
-        "SecretArn": str,
-        "StatementName": str,
-        "Status": StatusStringType,
-        "UpdatedAt": datetime,
-    },
-    total=False,
-)
 
-
-class StatementDataTypeDef(_RequiredStatementDataTypeDef, _OptionalStatementDataTypeDef):
-    pass
-
-
-_RequiredSubStatementDataTypeDef = TypedDict(
-    "_RequiredSubStatementDataTypeDef",
+SubStatementDataTypeDef = TypedDict(
+    "SubStatementDataTypeDef",
     {
         "Id": str,
+        "CreatedAt": NotRequired[datetime],
+        "Duration": NotRequired[int],
+        "Error": NotRequired[str],
+        "HasResultSet": NotRequired[bool],
+        "QueryString": NotRequired[str],
+        "RedshiftQueryId": NotRequired[int],
+        "ResultRows": NotRequired[int],
+        "ResultSize": NotRequired[int],
+        "Status": NotRequired[StatementStatusStringType],
+        "UpdatedAt": NotRequired[datetime],
     },
 )
-_OptionalSubStatementDataTypeDef = TypedDict(
-    "_OptionalSubStatementDataTypeDef",
-    {
-        "CreatedAt": datetime,
-        "Duration": int,
-        "Error": str,
-        "HasResultSet": bool,
-        "QueryString": str,
-        "RedshiftQueryId": int,
-        "ResultRows": int,
-        "ResultSize": int,
-        "Status": StatementStatusStringType,
-        "UpdatedAt": datetime,
-    },
-    total=False,
-)
-
-
-class SubStatementDataTypeDef(_RequiredSubStatementDataTypeDef, _OptionalSubStatementDataTypeDef):
-    pass
-
 
 TableMemberTypeDef = TypedDict(
     "TableMemberTypeDef",
     {
-        "name": str,
-        "schema": str,
-        "type": str,
+        "name": NotRequired[str],
+        "schema": NotRequired[str],
+        "type": NotRequired[str],
     },
-    total=False,
 )
